@@ -30,13 +30,12 @@ public:
     static QString configId(const KScreen::ConfigPtr &config);
     static bool configExists(const KScreen::ConfigPtr &config);
     static bool configExists(const QString& id);
-    static KScreen::ConfigPtr config(const KScreen::ConfigPtr &currentConfig, const QString& id);
+    static KScreen::ConfigPtr loadConfig(const KScreen::ConfigPtr &currentConfig, const QString& id);
     static bool saveConfig(const KScreen::ConfigPtr &config, const QString &configId);
     static void removeConfig(const QString &id);
     static bool moveConfig(const QString &srcId, const QString &destId);
 
     static KScreen::OutputPtr findOutput(const KScreen::ConfigPtr &config, const QVariantMap &info);
-    static QString outputId(const KScreen::OutputPtr &output);
     static QVariantMap metadata(const KScreen::OutputPtr &output);
 
     static void setConfigPath(const QString &path);
